pub struct ErrorEventData {
pub code: u16,
pub message: String,
}Expand description
Data returned on error event. The error event has a default handler that just logs that an error occurred. For a custom handler, register a handler on the ERROR_EVENT_NAME event.
Fields
code: u16message: StringTrait Implementations
Sourceimpl Clone for ErrorEventData
impl Clone for ErrorEventData
Sourcefn clone(&self) -> ErrorEventData
fn clone(&self) -> ErrorEventData
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ErrorEventData
impl Debug for ErrorEventData
Sourceimpl<'de> Deserialize<'de> for ErrorEventData
impl<'de> Deserialize<'de> for ErrorEventData
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Display for ErrorEventData
impl Display for ErrorEventData
Sourceimpl Error for ErrorEventData
impl Error for ErrorEventData
1.30.0 · Sourcefn source(&self) -> Option<&(dyn Error + 'static)>
fn source(&self) -> Option<&(dyn Error + 'static)>
Returns the lower-level source of this error, if any. Read more
1.0.0 · Sourcefn description(&self) -> &str
fn description(&self) -> &str
👎Deprecated since 1.42.0: use the Display impl or to_string()
Sourceimpl From<ErrorEventData> for Error
impl From<ErrorEventData> for Error
Sourcefn from(source: ErrorEventData) -> Self
fn from(source: ErrorEventData) -> Self
Converts to this type from the input type.